SystemOrganization addCategory: #'Phidget-EToys'!

PartsBin subclass: #PhdETPartsBin
	instanceVariableNames: 'controlingMorph'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-EToys'!

!PhdETPartsBin class methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 13:17'!
thumbnailForQuad: aQuint color: aColor phidget: aPhidget
	"Answer a thumbnail for a morph obtaining as per the quintuplet provided, creating the thumbnail if necessary.  If it is created afresh, it will also be cached at this time"

	| aThumbnail aSymbol formToThumbnail labeledItem |
	aSymbol := aQuint third.
	Thumbnails at: aSymbol ifPresent: [ :thumb | ^thumb ].
	formToThumbnail := aQuint at: 5 ifAbsent: [].
	formToThumbnail ifNil: [
		labeledItem := (Smalltalk at: aQuint first) perform: aQuint second with: aPhidget.
		formToThumbnail := labeledItem imageForm: 32 backgroundColor: aColor forRectangle: labeledItem fullBounds.
		formToThumbnail replaceColor: aColor withColor: Color transparent.
	].

	aThumbnail := Thumbnail new makeThumbnailFromForm: formToThumbnail.
	self cacheThumbnail: aThumbnail forSymbol: aSymbol.
	^ aThumbnail

"PartsBin initialize"! !

!PhdETPartsBin methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 11:47'!
controlingMorph
	^ controlingMorph! !

!PhdETPartsBin methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 11:48'!
controlingMorph: aMorph
	controlingMorph := aMorph.! !

!PhdETPartsBin methodsFor: 'as yet unclassified' stamp: 'pt 5/28/2009 13:20'!
listDirection: aListDirection quadList: quadList
	"Initialize the receiver to run horizontally or vertically, obtaining its elements from the list of tuples of the form:
		(<receiver> <selector> <label> <balloonHelp>)"

	| aButton aClass |
	self layoutPolicy: TableLayout new.
	self listDirection: aListDirection.
	self wrapCentering: #center.
	self layoutInset: 2.
	self cellPositioning: #bottomCenter.

	aListDirection == #leftToRight
		ifTrue:
			[self vResizing: #rigid.
			self hResizing: #spaceFill.
			self wrapDirection: #topToBottom]
		ifFalse:
			[self hResizing: #rigid.
			self vResizing: #spaceFill.
			self wrapDirection: #leftToRight].
	quadList do:
		[:tuple |
			aClass := Smalltalk at: tuple first.
			aButton := IconicButton new initializeWithThumbnail: (self class thumbnailForQuad: tuple color: self color phidget: self phidget) withLabel: tuple third andColor: self color andSend: tuple second to: aClass with: self phidget.
			(tuple size > 3 and: [tuple fourth isEmptyOrNil not]) ifTrue:
				[aButton setBalloonText: tuple fourth].
 			self addMorphBack: aButton]! !

!PhdETPartsBin methodsFor: 'as yet unclassified' stamp: 'pt 5/28/2009 17:11'!
phidget
	^ controlingMorph! !

BorderedMorph subclass: #PhdETPhidget
	instanceVariableNames: 'phidHandle labelMorph'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-EToys'!

!PhdETPhidget class methodsFor: 'as yet unclassified' stamp: 'pt 5/28/2009 14:26'!
additionsToViewerCategories
	"Answer a list of (<categoryName> <list of category specs>) pairs that characterize the phrases this kind of morph wishes to add to various Viewer categories."
	^ #(
		(Phidget (
			(slot Label 'The label of this Phidget.' String readWrite Player getLabel Player setLabel:)
			(slot Attached 'This is wether the Phidget is attached to the USB port or not.' Boolean readOnly Player getAttached unused unused)
		))
	)

! !

!PhdETPhidget methodsFor: 'private' stamp: 'pt 5/28/2009 14:38'!
adaptSize
	"Adjusts submorphs to fit perfectly - even if I was resized."
	
	self positionLabel.! !

!PhdETPhidget methodsFor: 'private' stamp: 'pt 5/28/2009 14:26'!
changed
	super changed.
	self adaptSize.! !

!PhdETPhidget methodsFor: 'initialization' stamp: 'pt 5/28/2009 14:54'!
createAndAddSubmorphs
	
	"create and add label"
	labelMorph := StringMorph new font: (TextStyle default fontAt: 2) emphasis: 1.
	self addMorph: labelMorph.! !

!PhdETPhidget methodsFor: 'submorphs-add/remove' stamp: 'pt 5/28/2009 14:41'!
delete
	phidHandle close.
	super delete.! !

!PhdETPhidget methodsFor: 'accessing' stamp: 'pt 5/28/2009 14:31'!
getAttached
	^ phidHandle attached! !

!PhdETPhidget methodsFor: 'accessing' stamp: 'pt 5/28/2009 14:31'!
getLabel
	^ labelMorph contents! !

!PhdETPhidget methodsFor: 'initialization' stamp: 'pt 5/28/2009 14:53'!
initPhidget: aPhidHandle withLabel: aLabel
	
	super initialize.
	phidHandle := aPhidHandle.
	self createAndAddSubmorphs.
	
	"Set standard size and color."
	self
		setLabel: aLabel;
		width: 290;
		height: 75;
		color: (Color r: 0.4 g: 0.7 b: 0.4);
		useRoundedCorners.
	
	"open the phidget, so that it's ready to be used"
	phidHandle openAny.! !

!PhdETPhidget methodsFor: 'private' stamp: 'pt 5/28/2009 14:31'!
positionLabel

	labelMorph position: self center - ( labelMorph width / 2 @ ( self height / 2 - 4 ) ).! !

!PhdETPhidget methodsFor: 'accessing' stamp: 'pt 5/28/2009 14:32'!
setLabel: anObject

	labelMorph contents: anObject asString.
	(self player) ifNotNil: [
		self player setName: labelMorph contents ].
	self adaptSize.
! !

PhdETPhidget subclass: #PhdETPortBasedPhidget
	instanceVariableNames: 'ports bin'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-EToys'!

PhdETPortBasedPhidget subclass: #PhdETInterfaceKit
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-EToys'!

!PhdETInterfaceKit class methodsFor: 'as yet unclassified' stamp: 'pt 5/3/2009 19:18'!
descriptionForPartsBin
    ^ self partName:    'InterfaceKit'
        categories:     #('Phidgets')
        documentation:  'An Interface Kit'! !

!PhdETInterfaceKit methodsFor: 'initialization' stamp: 'pt 5/28/2009 12:09'!
collectPortDescriptorQuads

	| quads |
	quads := OrderedCollection new.
	PhdETIfKitInputPort addPortDescriptorQuadsTo: quads.
	PhdETIfKitOutputPort addPortDescriptorQuadsTo: quads.
	PhdETIfKitSensorPort addPortDescriptorQuadsTo: quads.
	^ quads! !

!PhdETInterfaceKit methodsFor: 'accessing' stamp: 'pt 5/28/2009 11:26'!
getInput: index
	^ phidHandle inputValue: index! !

!PhdETInterfaceKit methodsFor: 'accessing' stamp: 'pt 5/28/2009 11:26'!
getOutput: index
	^ phidHandle outputValue: index! !

!PhdETInterfaceKit methodsFor: 'accessing' stamp: 'pt 5/28/2009 11:27'!
getSensor: index
	^ phidHandle sensorValue: index! !

!PhdETInterfaceKit methodsFor: 'initialization' stamp: 'pt 5/28/2009 11:34'!
initializeToStandAlone
	
	self initPhidget: PhdCrInterfaceKit new withLabel: 'Interface Kit'.! !

!PhdETInterfaceKit methodsFor: 'accessing' stamp: 'pt 5/28/2009 11:35'!
inputPortAvailable: portNumber
	^ phidHandle inputIndexIsInRange: portNumber! !

!PhdETInterfaceKit methodsFor: 'accessing' stamp: 'pt 5/28/2009 11:35'!
outputPortAvailable: portNumber
	^ phidHandle outputIndexIsInRange: portNumber! !

!PhdETInterfaceKit methodsFor: 'accessing' stamp: 'pt 5/28/2009 11:35'!
sensorPortAvailable: portNumber
	^ phidHandle sensorIndexIsInRange: portNumber! !

!PhdETInterfaceKit methodsFor: 'accessing' stamp: 'pt 5/28/2009 11:35'!
setOutput: index to: aBoolean
	^ phidHandle setOutputValue: aBoolean at: index! !

!PhdETPortBasedPhidget methodsFor: 'as yet unclassified' stamp: 'pt 5/28/2009 14:38'!
adaptSize
	"Adjusts submorphs to fit perfectly - even if I was resized."
	
	self positionBin.
	self positionLabel.! !

!PhdETPortBasedPhidget methodsFor: 'initialization' stamp: 'pt 5/28/2009 17:09'!
createAndAddSubmorphs
	
	"create and add bin"
	super createAndAddSubmorphs.
	bin := self createBin.
	self addMorph: bin.! !

!PhdETPortBasedPhidget methodsFor: 'initialization' stamp: 'pt 5/28/2009 12:04'!
createBin
	
	| oldResizing aBin |
	aBin := (PhdETPartsBin newPartsBinWithOrientation: #leftToRight from: #())
		listDirection: #leftToRight;
		wrapDirection: #topToBottom;
		setNameTo: 'Ports';
		dropEnabled: false;
		useRoundedCorners;
		controlingMorph: self;
		yourself.

	oldResizing := aBin vResizing.
	aBin
		listDirection: #leftToRight quadList: self collectPortDescriptorQuads;
		vResizing: oldResizing;
		layoutChanged;
		fullBounds.
		
	^ aBin! !

!PhdETPortBasedPhidget methodsFor: 'submorphs-add/remove' stamp: 'pt 5/28/2009 17:09'!
delete
	ports reverseDo: [ :port | port delete ].
	super delete.! !

!PhdETPortBasedPhidget methodsFor: 'initialization' stamp: 'pt 5/28/2009 17:09'!
initPhidget: aPhidHandle withLabel: aLabel
	
	ports := OrderedCollection new.
	super initPhidget: aPhidHandle withLabel: aLabel.	
	bin color: self color lighter lighter.! !

!PhdETPortBasedPhidget methodsFor: 'private' stamp: 'pt 5/28/2009 17:09'!
positionBin
		
	bin
		height: self height - 20;
		top: self top + 17;
		width: self width - 6;
		left: self left + 3.! !

!PhdETPortBasedPhidget methodsFor: 'port handling' stamp: 'pt 5/28/2009 17:10'!
registerPort: aPort
	"If a new Port was draged out of me, it registeres itself here."
	
	ports add: aPort.! !

!PhdETPortBasedPhidget methodsFor: 'port handling' stamp: 'pt 5/28/2009 17:10'!
unregisterPort: aPort
	"If a new Port was draged out of me, it registeres itself here."
	
	ports remove: aPort ifAbsent: [].! !

PhdETPhidget subclass: #PhdETServo1Motor
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-EToys'!

!PhdETServo1Motor class methodsFor: 'as yet unclassified' stamp: 'pt 5/28/2009 17:08'!
additionsToViewerCategories
	"Answer a list of (<categoryName> <list of category specs>) pairs that characterize the phrases this kind of morph wishes to add to various Viewer categories."
	^ #(
		(Phidget (
			(slot Attached 'This is wether the Phidget is attached to the USB port or not.' Boolean readOnly Player getAttached unused unused)
			(slot Engaged 'This is wether the servo motor is engaged or not.' Boolean readWrite Player getEngaged Player setEngaged:)
		))
	)

! !

!PhdETServo1Motor class methodsFor: 'as yet unclassified' stamp: 'pt 5/29/2009 09:37'!
descriptionForPartsBin
    ^ self partName:    'Servo 1-Motor'
        categories:     #('Phidgets')
        documentation:  'A Servo Board which connects to 1 servo motor.'! !

!PhdETServo1Motor methodsFor: 'as yet unclassified' stamp: 'pt 5/28/2009 12:08'!
collectPortDescriptorQuads

	| quads |
	quads := OrderedCollection new.
	PhdETServoMotorPort addPortDescriptorQuadsTo: quads.
	^ quads! !

!PhdETServo1Motor methodsFor: 'as yet unclassified' stamp: 'pt 5/28/2009 17:08'!
getEngaged
	^ true! !

!PhdETServo1Motor methodsFor: 'as yet unclassified' stamp: 'pt 5/28/2009 12:18'!
initializeToStandAlone
	
	self initPhidget: PhdCrServo new withLabel: 'Servo Board'.
	self width: 110.! !

!PhdETServo1Motor methodsFor: 'as yet unclassified' stamp: 'pt 5/28/2009 17:08'!
setEngaged: aBoolean
! !

BorderedMorph subclass: #PhdETPort
	instanceVariableNames: 'Phidget portNumber numberString Wire'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-EToys'!

PhdETPort subclass: #PhdETIfKitInputPort
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-EToys'!

!PhdETIfKitInputPort class methodsFor: 'as yet unclassified' stamp: 'pt 5/8/2009 08:57'!
additionsToViewerCategoryInputPort
	"Answer a list of (<categoryName> <list of category specs>) pairs that characterize the phrases this kind of morph wishes to add to various Viewer categories."
	
	^ #(
		InputPort (
			(slot Value 'The value at the digital Intput port on an Interface Kit.' Boolean readOnly Player getIfKitInputValue unused unused)
			(slot PortNumber 'The index of this digital Input port.' Number readWrite Player getPortNumber Player setPortNumber:)
			(slot ShowWire 'This is wether a wire from this port to its Phidget is shown..' Boolean readWrite Player getShowWire Player setShowWire:)
		)
	)! !

!PhdETIfKitInputPort class methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 08:32'!
portDescription

	^  self
		partName:		'Digital Input'
		categories:		#('Interface Kit')
		documentation:	'An port to a digital input of an Interface Kit. This port is bound to a port of the Interface Kit hardware. With me it is possible to read wether the port returns true or false.'.! !

!PhdETIfKitInputPort methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 15:00'!
getIfKitInputValue
	^ Phidget getInput: portNumber! !

!PhdETIfKitInputPort methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 12:39'!
initialize
	super initialize.
	self color: Color red lighter.! !

!PhdETIfKitInputPort methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 19:07'!
isInRange: aNumber
	
	^ Phidget sensorPortAvailable: aNumber! !

PhdETPort subclass: #PhdETIfKitOutputPort
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-EToys'!

!PhdETIfKitOutputPort class methodsFor: 'as yet unclassified' stamp: 'pt 5/8/2009 08:58'!
additionsToViewerCategoryOutputPort
	"Answer a list of (<categoryName> <list of category specs>) pairs that characterize the phrases this kind of morph wishes to add to various Viewer categories."

	^ #(
		OutputPort (
			(slot Value 'The value at the digital Output port on an Interface Kit.' Boolean readWrite Player getIfKitOutputValue Player setIfKitOutputValue:)
			(slot PortNumber 'The index of this digital Output port.' Number readWrite Player getPortNumber Player setPortNumber:)
			(slot ShowWire 'This is wether a wire from this port to its Phidget is shown..' Boolean readWrite Player getShowWire Player setShowWire:)
		)
	)! !

!PhdETIfKitOutputPort class methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 08:32'!
portDescription

	^  self
		partName:		'Digital Output'
		categories:		#('Interface Kit')
		documentation:	'An port to a digital output of an Interface Kit. This port is bound to a port of the Interface Kit hardware. With me it is possible to read wether the port returns true or false or set this value'.! !

!PhdETIfKitOutputPort methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 15:00'!
getIfKitOutputValue
	^ Phidget getOutput: portNumber! !

!PhdETIfKitOutputPort methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 19:14'!
initialize
	super initialize.
	self color: Color blue muchLighter.! !

!PhdETIfKitOutputPort methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 19:09'!
isInRange: aNumber
	
	^ Phidget outputPortAvailable: aNumber! !

!PhdETIfKitOutputPort methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 15:00'!
setIfKitOutputValue: aBoolean
	^ Phidget setOutput: portNumber to: aBoolean.! !

PhdETPort subclass: #PhdETIfKitSensorPort
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-EToys'!

!PhdETIfKitSensorPort class methodsFor: 'as yet unclassified' stamp: 'pt 5/8/2009 08:59'!
additionsToViewerCategorySensorPort
	"Answer a list of (<categoryName> <list of category specs>) pairs that characterize the phrases this kind of morph wishes to add to various Viewer categories."

	^ #(
		SensorPort (
			(slot Value 'The value at the analog Sensor port on an Interface Kit.' Number readOnly Player getIfKitSensorValue unused unused)
			(slot SensorPortNumber 'The index of this analog Sensor port.' Number readWrite Player getPortNumber Player setPortNumber:)
			(slot ShowWire 'This is wether a wire from this port to its Phidget is shown..' Boolean readWrite Player getShowWire Player setShowWire:)
		)
	)! !

!PhdETIfKitSensorPort class methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 08:32'!
portDescription

	^  self
		partName:		'Analog Sensor'
		categories:		#('Interface Kit')
		documentation:	'An port to an analog sensor of an Interface Kit. This port is bound to a port of the Interface Kit hardware. With me it is possible to read which value an attached analog sensor returns. This value is between 0 and 1000.'.! !

!PhdETIfKitSensorPort methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 15:00'!
getIfKitSensorValue
	^ Phidget getSensor: portNumber! !

!PhdETIfKitSensorPort methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 12:39'!
initialize
	super initialize.
	self color: Color yellow lighter.! !

!PhdETIfKitSensorPort methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 19:09'!
isInRange: aNumber
	
	^ Phidget inputPortAvailable: aNumber! !

!PhdETPort class methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 08:17'!
addPortDescriptorQuadsTo: aList
	"analogous to addPartsDescriptorQuadsTo: aList if: aBlock from the Morph class"
	
	| info |
	info := self portDescription.
	aList add:
		{info globalReceiverSymbol.
		info nativitySelector.
		info formalName.
		info documentation.
		info sampleImageFormOrNil}.! !

!PhdETPort class methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 12:00'!
launchPartVia: aSelector label: aString phidget: aPhidget
	"Obtain a morph by sending aSelector to self, and attach it to the morphic hand.  This provides a general protocol for parts bins"

	| aMorph |
	aMorph := self perform: aSelector with: aPhidget.
	aMorph setNameTo: (ActiveWorld unusedMorphNameLike: aString).
	aMorph setProperty: #beFullyVisibleAfterDrop toValue: true.
	aMorph openInHand! !

!PhdETPort class methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 10:54'!
newStandAlone: aPhidget
	"Answer an instance capable of standing by itself as a usable morph."

	^ self basicNew initializeToStandAlone: aPhidget! !

!PhdETPort class methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 10:52'!
partName: aName categories: aList documentation: aDoc
	"Answer a DescriptionForPartsBin which will represent a launch of a new instance of my class via the #newStandAlone protocol sent to my class. Use the category-list and documentation provided"


	^ DescriptionForPartsBin new
		formalName: aName
		categoryList: aList
		documentation: aDoc
		globalReceiverSymbol: self name
		nativitySelector: #newStandAlone:! !

!PhdETPort class methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 08:18'!
portDescription

	self subclassResponsibility.
	! !

!PhdETPort methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 09:51'!
centerNumberString.
	numberString position: self center - ((numberString width / 2)@( numberString height / 2)).! !

!PhdETPort methodsFor: 'as yet unclassified' stamp: 'pt 5/28/2009 14:18'!
delete
	Wire delete.
	Phidget unregisterPort: self.
	super delete.! !

!PhdETPort methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 09:28'!
getPortNumber
	^ portNumber! !

!PhdETPort methodsFor: 'as yet unclassified' stamp: 'pt 5/28/2009 14:05'!
initialize

	super initialize.
	self useRoundedCorners.
	portNumber := 1.
	numberString := StringMorph new contents: portNumber asString.
	self
		centerNumberString;
		addMorph: numberString.
	Wire := LineMorph new.
	self currentWorld addMorphBack: Wire.! !

!PhdETPort methodsFor: 'as yet unclassified' stamp: 'pt 5/8/2009 11:34'!
initializeToStandAlone: aPhidget
	Phidget := aPhidget.
	Phidget registerPort: self.
	self initialize.
	! !

!PhdETPort methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 19:05'!
isInRange: aNumber
	"A subclass may override this, to allow changing portNumbers"
	^ false! !

!PhdETPort methodsFor: 'as yet unclassified' stamp: 'pt 5/20/2009 15:50'!
positionWire
	Wire setVertices: {Phidget center. self center}.! !

!PhdETPort methodsFor: 'as yet unclassified' stamp: 'pt 5/7/2009 19:11'!
setPortNumber: aNumber
	( aNumber isInteger and: [ self isInRange: aNumber ] )
	ifTrue: [
		portNumber := aNumber.
		numberString contents: portNumber asString.
		self centerNumberString ]! !

!PhdETPort methodsFor: 'as yet unclassified' stamp: 'pt 5/8/2009 09:23'!
step
	self positionWire.! !

!PhdETPort methodsFor: 'as yet unclassified' stamp: 'pt 5/8/2009 09:22'!
stepTime
	^ 100! !

PhdETPort subclass: #PhdETServoMotorPort
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-EToys'!

!PhdETServoMotorPort class methodsFor: 'as yet unclassified' stamp: 'pt 5/22/2009 22:54'!
additionsToViewerCategorySensorPort
	"Answer a list of (<categoryName> <list of category specs>) pairs that characterize the phrases this kind of morph wishes to add to various Viewer categories."

	^ #(
		ServoMotor (
			(slot Position 'The current position of the servo motor at the current port.' Number readWrite Player getServoPosition Player setServoPosition)
			(slot MaxPosition 'The max. possible position of this servo motor.' Number readOnly Player getServoMaxPosition unused unused)
			(slot MinPosition 'The max. possible position of this servo motor.' Number readOnly Player getServoMinPosition unused unused)
			(slot PortNumber 'The index of this motor on the Servo board.' Number readWrite Player getPortNumber Player setPortNumber:)
			(slot ShowWire 'This is wether a wire from this port to its Phidget is shown..' Boolean readWrite Player getShowWire Player setShowWire:)
		)
	)! !

!PhdETServoMotorPort class methodsFor: 'as yet unclassified' stamp: 'pt 5/8/2009 08:26'!
portDescription

	^  self
		partName:		'Motor Position'
		categories:		#('Servo Board')
		documentation:	'An port to a motor on the Servo board. Its value is between the minValue and maxValue.'.! !

!PhdETServoMotorPort methodsFor: 'as yet unclassified' stamp: 'pt 5/8/2009 08:35'!
getServoMaxPosition
	^ 0! !

!PhdETServoMotorPort methodsFor: 'as yet unclassified' stamp: 'pt 5/8/2009 08:35'!
getServoMinPosition
	^ 0! !

!PhdETServoMotorPort methodsFor: 'as yet unclassified' stamp: 'pt 5/8/2009 08:35'!
getServoPosition
	^ 0! !

!PhdETServoMotorPort methodsFor: 'as yet unclassified' stamp: 'pt 5/28/2009 12:25'!
initialize
	super initialize.
	self color: (Color r:0.45 g:0.45 b:1).! !

!PhdETServoMotorPort methodsFor: 'as yet unclassified' stamp: 'pt 5/8/2009 08:36'!
isInRange: aNumber
	
	^ false! !
